function [novl,jacx,jacy]=meshq1_ie(nov,nvl,xy,ipar);
% MESHQ1_IE Construction of extended Q1 mesh
%
% [novl,jacx,jacy]=meshq1_ie(nov,nvl,xy,ipar);
%
% called by stiffq1.m
%
% Input: 
%        nov = local -global map, previously generated by cosnov_2d
%        nvl = number of nodes in each spectral element
%        xy = column array with global mesh, length: noe=nov(npdx*npdy,ne)
%        ipar = arry woth internal parameters.
%
% Output:
%        novl =  2-indexes array. It maps  Q1 mesh on the Qn extended element 
%        jacx, jacy = jacobians of Q1 mesh on the extended element
%

%   Written by Paola Gervasio
%   $Date: 2007/04/01$

%

noe=nvl(1);ne=ipar(6);npxl=ipar(1);npyl=ipar(2);mn=ipar(3);
nexl=nvl(2); neyl=nvl(3);
novl=zeros(4,ne);
npx=nexl+1;
jacx=zeros(ne,1); jacy=zeros(ne,1);
for i=1:nexl
for j=1:neyl
    k=(j-1)*npx+i;  iel=(j-1)*nexl+i;
    i1=k;i2=k+1;i3=k+npx;i4=k+npx+1;
    novl(1:4,iel)=[i1;i2;i3;i4];
    jacx(iel)=(xy(i2,1)-xy(i1,1))*0.5;
    jacy(iel)=(xy(i3,2)-xy(i1,2))*0.5;
end
end


            
       
    

