function [Ac,Acb,wwc,lista_coarse,noec,novc,lintc,ldirc]=...
    stiffq1H(nx,nex,ny,ney,xy,nov,ifro);
% STIFFQ1H Construction of stiffness Q1 matrix on the coarse grid.
% 
% [Ac,Acb,wwc,lista_coarse,noec,novc,lintc,ldirc]=...
%   stiffq1H(nx,nex,ny,ney,xy,nov,ifro);
%
%   called by schwarz_2d.m and b eig_schwarz_2d.m
%
% Input:  
%        nx = polynomial degree in each element (the same in each element)
%               along x-direction
%        nex = number of elements (equally spaced) along x-direction
%        ny = polynomial degree in each element (the same in each element)
%               along y-direction%        gammax = column or row array of length nex-1. 
%        ney = number of elements (equally spaced) along y-direction
%        xy = column array with global mesh, length: noe=nov(npdx*npdy,ne)
%        nov = local -global map, previously generated by cosnov_2d
%        ifro = column array of length noe=nov(npdx*npdy,ne):
%            if (x_i,y_i) is internal to Omega then ifro(i)=0,
%            if (x_i,y_i) is on \partial\Omega then ifro(i)=1,
%
% Output:
%        Ac =  Cholesky factor of the Q1 stiffness matrix (internal/internal nodes) 
%               on the coarse mesh
%        Acb = Q1 stiffness matrix (internal/boundary nodes) 
%               on the coarse mesh
%        wwc = Q1 mass matrix (internal nodes) 
%                on the coarse mesh
%        lista_coarse = list of nodes of Omega wich are nodes of teh coarse mesh
%        noec = number of nodes of the coarse mesh
%        novc(4,ne) = it maps each macro-Q1 element on the coarse mesh Q1
%        lintc = lista of internal nodes of the coarse mesh
%        ldirc = lista of boudanry nodes of the coarse mesh
%
% References: CHQZ2 = C. Canuto, M.Y. Hussaini, A. Quarteroni, T.A. Zang,
%                    "Spectral Methods. Fundamentals in Single Domains"
%                    Springer Verlag, Berlin Heidelberg New York, 2006.
%             CHQZ3 = C. Canuto, M.Y. Hussaini, A. Quarteroni, T.A. Zang,
%                    "Spectral Methods. Evolution to Complex Geometries 
%                     and Applications to Fluid DynamicsSpectral Methods"
%                    Springer Verlag, Berlin Heidelberg New York, 2007.

%   Written by Paola Gervasio
%   $Date: 2007/04/01$

npdx=nx+1;npdy=ny+1;ne=nex*ney;
npxc=nex+1;npyc=ney+1;noec=npxc*npyc;
mn=npdx*npdy;nm1=mn-npdx+1;

% costruisco la mesh coarse
[lista_coarse,novc,novcg,jacxe,jacye]=meshq1_coarse(npdx,npdy,nov,xy);
noec=length(lista_coarse);

xyc=zeros(noec,2); xyc(:,1)=xy(lista_coarse,1);xyc(:,2)=xy(lista_coarse,2);
ifroc=zeros(noec,1); ifroc=ifro(lista_coarse);

x=[-1;1]; wx=[1;1]; dx=[-0.5,0.5;-0.5,0.5];
y=x;wy=wx;dy=dx;
iparl=zeros(10,1);
iparl(7)=noec;iparl(6)=ne;iparl(1)=2;iparl(2)=2;iparl(3)=4;



% costruisco la matrice Q1 del laplaciano sull'elemento esteso.
[Ac,wwc]=stiffq1_se(iparl,ifroc,novc,wx,dx,jacxe,wy,dy,jacye);

% filtro la matrice sui nodi interni e sui nodi di bordo
% e costruisco la fattorizzazione di Cholesky di Al

 [ldirc,lintc]=liste1(ifroc);
 Acb=Ac(lintc,ldirc);
 Ac=Ac(lintc,lintc);
 wwc=wwc(lintc);
 Ac=chol(Ac);
 
 return
