function [A,ww]=stiffq1_se(ipar,ifro,nov,wx,dx,jacx,wy,dy,jacy);
% STIFFQ1_SE Assembles Q1 stiffness local matrices on extended elements
%
% [A,ww]=stiffq1_se(ipar,ifro,nov,wx,dx,jacx,wy,dy,jacy);
%
% Input: ipar = array of parameters, set in the calling function
%        ifro  = column array of length noe=nov(npdx*npdy,ne):
%            if (x_i,y_i) is internal to Omega then ifro(i)=0,
%            if (x_i,y_i) is on \partial\Omega then ifro(i)=1,
%        nov = local -global map, previously generated by cosnov_2d
%         wx = npdx LGL weigths in [-1,1],
%            (produced by calling [x,wx]=xwlgl(npdx))
%         dx =first derivative LGL matrix (by calling dx=derlgl(x,npdx))
%         jacx = array (length(jacx)=ne); jacx(ie)= (x_V2_ie-x_V1_ie)/2
%         wy = npdy LGL weigths in [-1,1],
%            (produced by calling [y,wy]=xwlgl(npdy))
%         dy =first derivative LGL matrix (by calling dy=derlgl(y,npdy))
%         jacy = array (length(jacy)=ne); jacy(ie)= (y_V3_ie-y_V1_ie)/2
% 
% Output: A = local stiffness Q1 matrix on the extended macro element
%         ww = local mass Q1 matrix on the extended macro element
%
% References: CHQZ2 = C. Canuto, M.Y. Hussaini, A. Quarteroni, T.A. Zang,
%                    "Spectral Methods. Fundamentals in Single Domains"
%                    Springer Verlag, Berlin Heidelberg New York, 2006.
%             CHQZ3 = C. Canuto, M.Y. Hussaini, A. Quarteroni, T.A. Zang,
%                    "Spectral Methods. Evolution to Complex Geometries 
%                     and Applications to Fluid DynamicsSpectral Methods"
%                    Springer Verlag, Berlin Heidelberg New York, 2007.

%   Written by Paola Gervasio
%   $Date: 2007/04/01$


noe=ipar(7); ne=ipar(6); npdx=ipar(1); npdy=ipar(2); mn=ipar(3);
A=sparse(noe,noe);
ww=zeros(noe,1);
for ie=1:ne
jac=jacx(ie)*jacy(ie);
[Al]=stiff_2d_sp(wx,dx,jacx(ie),wy,dy,jacy(ie));
A(nov(1:mn,ie),nov(1:mn,ie))=A(nov(1:mn,ie),nov(1:mn,ie))+Al;   
ww(nov(1:mn,ie))=ww(nov(1:mn,ie))+ones(4,1)*jac;
end

