function [A]=stiff_3d_se(npdx,nex,npdy,ney,npdz,nez,nov,wx,dx,jacx,wy,dy,jacy,wz,dz,jacz);
% STIFF_3D_SE Assembles 3D global stiffness SEM matrix associated to (nabla(phi_j), nabla(phi_i))
%
%     (nabla(phi_j), nabla(phi_i))_N 
%
%
%    [A]=stiff_3d_se(npdx,nex,npdy,ney,npdz,nez,nov,wx,dx,jacx,wy,dy,jacy,wz,dz,jacz);
%        produces the matrix
%        A_{ij}=(nabla(phi_j), nabla(phi_i))_N
%        of size
%        (noe,noe) where noe=nov(npdx*npdy*npdz,ne) is the number of d.o.f.
%
% Input : npdx = polynomial degree in every element along x-direction
%         nex = number of elements (equally spaced) along x-direction
%         npdy = polynomial degree in every element along y-direction
%         ney = number of elements (equally spaced) along y-direction
%         npdz = polynomial degree in every element along z-direction
%         nez= number of elements (equally spaced) along z-direction
%         nov = local -global map, previously generated by mesh_3d
%         wx = npdx LGL weigths in [-1,1],
%            (produced by calling [x,wx]=xwlgl(npdx))
%         dx =first derivative LGL matrix (produced by calling dx=derlgl(x,npdx))
%         jacx = array (length(jacx)=ne); jacx(ie)= (x_V2_ie-x_V1_ie)/2
%         wy = npdy LGL weigths in [-1,1],
%            (produced by calling [y,wy]=xwlgl(npdy))
%         dy =first derivative LGL matrix (produced by calling dy=derlgl(y,npdy))
%         jacy = array (length(jacy)=ne); jacy(ie)= (y_V3_ie-y_V1_ie)/2
%         wz = npdy LGL weigths in [-1,1],
%            (produced by calling [z,wz]=xwlgl(npdz))
%         dz =first derivative LGL matrix (produced by calling dz=derlgl(z,npdz)
%         jacz = array (length(jacy)=ne); jacz(ie)= (y_V5_ie-y_V1_ie)/2
%
%
% Output: A = matrix (noe,noe)
%
%
% Reference: CHQZ2 = C. Canuto, M.Y. Hussaini, A. Quarteroni, T.A. Zang,
%                    "Spectral Methods. Fundamentals in Single Domains"
%                    Springer Verlag, Berlin Heidelberg New York, 2006.

%   Written by Paola Gervasio
%   $Date: 2007/04/01$

[ldnov,ne]=size(nov);
noe=nov(ldnov,ne);
A=sparse(noe,noe);
for ie=1:ne
Al=stiff_3d_sp(wx,dx,jacx(ie),wy,dy,jacy(ie),wz,dz,jacz(ie));
A(nov(1:ldnov,ie),nov(1:ldnov,ie))=A(nov(1:ldnov,ie),nov(1:ldnov,ie))+Al;
end

